@@ -83,6 +83,7 @@ Request <- struct(
 #' @param operation An operation, e.g. from `new_operation`.
 #' @param params A populated input object.
 #' @param data An empty output object.
+#' @param dest Control where the response body is written
 #'
 #' @family API request functions
 #'
@@ -101,7 +102,7 @@ Request <- struct(
 #' }
 #'
 #' @export
-new_request <- function(client, operation, params, data) {
+new_request <- function(client, operation, params, data, dest = NULL) {
 
   method <- operation$http_method
   if (is.null(method)) {
@@ -113,7 +114,8 @@ new_request <- function(client, operation, params, data) {
     url = "",
     body = NULL,
     close = client$config$close_connection,
-    timeout = client$config$timeout
+    timeout = client$config$timeout,
+    dest = dest
   )
 
   http_req$url <- parse_url(
